//  File: Thermistor.h
//
//  Use a voltage divider to indicate electrical resistance of a thermistor
//  Thermistor reading and T conversion are encapsulated in reusable objects
//
//     Vdd ---o    Vdd is supply voltage, typically 5V
//            |
//            Rt   (thermistor)
//            |
//      Vo ---o    Vo is output from the voltage divider:  Vo = Vdd*R/(R+Rt)
//            |
//            R    (fixed resistor, R approx. equal to Rt
//            |
//           GND
//
//  Based on code by Max Mayfield, max.mayfield@hotmail.com
//  posted on the Arduino playground
//  http://www.arduino.cc/playground/ComponentLib/Thermistor2
//  Modified and extended by G. Recktenwald, recktenwaldg@gmail.com
//  2010-06-07

#ifndef Thermistor_h

#define Thermistor_h
#include "WProgram.h"
#include "math.h"

class Thermistor {

	public:
		Thermistor(int pin);
		float  getTemp();
		void   fixedResistance(float Rfix);
		void   coefficients(float a1, float a2, float a3);

	private:
		int    _pin;
		float  _Rfix;
		float  _a1, _a2, _a3;
};

#endif
